@@ -15,7 +15,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_array_type(&mut self, n: &TsArrayType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.elem_type);
         punct!("[");
@@ -24,7 +24,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_as_expr(&mut self, n: &TsAsExpr) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.expr);
 
@@ -37,7 +37,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_call_signature_decl(&mut self, n: &TsCallSignatureDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.type_params);
 
@@ -56,7 +56,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_cond_type(&mut self, n: &TsConditionalType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.check_type);
         space!();
@@ -80,7 +80,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_constructor_signature_decl(&mut self, n: &TsConstructSignatureDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("constructor");
 
@@ -91,7 +91,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_constructor_type(&mut self, n: &TsConstructorType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.is_abstract {
             keyword!("abstract");
@@ -117,7 +117,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_entity_name(&mut self, n: &TsEntityName) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n {
             TsEntityName::TsQualifiedName(n) => {
@@ -129,7 +129,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_enum_decl(&mut self, n: &TsEnumDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.declare {
             keyword!("declare");
@@ -156,7 +156,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_enum_member(&mut self, n: &TsEnumMember) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.id);
 
@@ -178,7 +178,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_export_assignment(&mut self, n: &TsExportAssignment) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("export");
         formatting_space!();
@@ -189,7 +189,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_expr_with_type_args(&mut self, n: &TsExprWithTypeArgs) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.expr);
 
@@ -198,14 +198,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_external_module_ref(&mut self, n: &TsExternalModuleRef) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         unimplemented!("emit_ts_external_module_ref")
     }
 
     #[emitter]
     fn emit_ts_fn_or_constructor_type(&mut self, n: &TsFnOrConstructorType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n {
             TsFnOrConstructorType::TsFnType(n) => emit!(n),
@@ -225,7 +225,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_fn_type(&mut self, n: &TsFnType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.type_params);
 
@@ -242,7 +242,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_import_equals_decl(&mut self, n: &TsImportEqualsDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.is_export {
             keyword!("export");
@@ -259,7 +259,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_index_signature(&mut self, n: &TsIndexSignature) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("[");
         self.emit_list(n.span, Some(&n.params), ListFormat::Parameters)?;
@@ -274,7 +274,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_index_accessed_type(&mut self, n: &TsIndexedAccessType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.obj_type);
 
@@ -285,7 +285,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_infer_type(&mut self, n: &TsInferType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("infer");
         space!();
@@ -294,7 +294,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_interface_body(&mut self, n: &TsInterfaceBody) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("{");
 
@@ -305,7 +305,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_interface_decl(&mut self, n: &TsInterfaceDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.declare {
             keyword!("declare");
@@ -338,7 +338,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_intersection_type(&mut self, n: &TsIntersectionType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         self.emit_list(
             n.span,
@@ -349,7 +349,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_keyword_type(&mut self, n: &TsKeywordType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n.kind {
             TsKeywordTypeKind::TsAnyKeyword => keyword!(n.span, "any"),
@@ -383,7 +383,7 @@ impl<'a> Emitter<'a> {
     fn emit_ts_tpl_lit(&mut self, node: &TsTplLitType) -> Result {
         debug_assert!(node.quasis.len() == node.types.len() + 1);
 
-        self.emit_leading_comments_of_pos(node.span().lo(), false)?;
+        self.emit_leading_comments_of_span(node.span(), false)?;
 
         punct!("`");
         let i = 0;
@@ -403,14 +403,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_lit_type(&mut self, n: &TsLitType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.lit);
     }
 
     #[emitter]
     fn emit_ts_mapped_type(&mut self, n: &TsMappedType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("{");
         self.wr.write_line()?;
@@ -485,7 +485,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_method_signature(&mut self, n: &TsMethodSignature) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.readonly {
             keyword!("readonly");
@@ -521,12 +521,12 @@ impl<'a> Emitter<'a> {
     #[emitter]
     fn emit_ts_module_block(&mut self, n: &TsModuleBlock) -> Result {
         self.emit_list(n.span, Some(&n.body), ListFormat::SourceFileStatements)?;
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
     }
 
     #[emitter]
     fn emit_ts_module_decl(&mut self, n: &TsModuleDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.declare {
             keyword!("declare");
@@ -553,14 +553,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_module_ref(&mut self, n: &TsModuleRef) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         unimplemented!("emit_ts_module_ref")
     }
 
     #[emitter]
     fn emit_ts_ns_body(&mut self, n: &TsNamespaceBody) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("{");
         self.wr.increase_indent()?;
@@ -574,14 +574,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_ns_decl(&mut self, n: &TsNamespaceDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         unimplemented!("emit_ts_ns_decl")
     }
 
     #[emitter]
     fn emit_ts_ns_export_decl(&mut self, n: &TsNamespaceExportDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("export");
         space!();
@@ -592,7 +592,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_non_null_expr(&mut self, n: &TsNonNullExpr) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.expr);
         punct!("!")
@@ -600,7 +600,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_optional_type(&mut self, n: &TsOptionalType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.type_ann);
         punct!("?");
@@ -608,7 +608,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_param_prop(&mut self, n: &TsParamProp) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         self.emit_accesibility(n.accessibility)?;
 
@@ -622,7 +622,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_param_prop_param(&mut self, n: &TsParamPropParam) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n {
             TsParamPropParam::Ident(n) => emit!(n),
@@ -632,7 +632,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_paren_type(&mut self, n: &TsParenthesizedType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("(");
         emit!(n.type_ann);
@@ -641,7 +641,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_property_signature(&mut self, n: &TsPropertySignature) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.readonly {
             keyword!("readonly");
@@ -682,7 +682,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_qualified_name(&mut self, n: &TsQualifiedName) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.left);
         punct!(".");
@@ -691,7 +691,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_rest_type(&mut self, n: &TsRestType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("...");
         emit!(n.type_ann);
@@ -699,14 +699,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_this_type(&mut self, n: &TsThisType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!(n.span, "this");
     }
 
     #[emitter]
     fn emit_ts_this_type_or_ident(&mut self, n: &TsThisTypeOrIdent) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n {
             TsThisTypeOrIdent::TsThisType(n) => emit!(n),
@@ -716,7 +716,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_tuple_type(&mut self, n: &TsTupleType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("[");
         self.emit_list(n.span, Some(&n.elem_types), ListFormat::TupleTypeElements)?;
@@ -725,7 +725,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_tuple_element(&mut self, n: &TsTupleElement) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if let Some(label) = &n.label {
             emit!(label);
@@ -764,7 +764,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_import_type(&mut self, n: &TsImportType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("import");
         punct!("(");
@@ -785,7 +785,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_alias_decl(&mut self, n: &TsTypeAliasDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.declare {
             keyword!("declare");
@@ -813,14 +813,14 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_ann(&mut self, n: &TsTypeAnn) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.type_ann)
     }
 
     #[emitter]
     fn emit_ts_type_assertion(&mut self, n: &TsTypeAssertion) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("<");
         emit!(n.type_ann);
@@ -830,7 +830,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_const_assertion(&mut self, n: &TsConstAssertion) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.expr);
 
@@ -890,7 +890,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_lit(&mut self, n: &TsTypeLit) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("{");
         self.emit_list(
@@ -903,7 +903,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_operator(&mut self, n: &TsTypeOperator) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         match n.op {
             TsTypeOperatorOp::KeyOf => keyword!("keyof"),
@@ -916,7 +916,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_param(&mut self, n: &TsTypeParam) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.name);
 
@@ -937,7 +937,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_param_decl(&mut self, n: &TsTypeParamDecl) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("<");
 
@@ -948,7 +948,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_param_instantiation(&mut self, n: &TsTypeParamInstantiation) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         punct!("<");
         self.emit_list(n.span, Some(&n.params), ListFormat::TypeParameters)?;
@@ -958,7 +958,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_predicate(&mut self, n: &TsTypePredicate) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         if n.asserts {
             keyword!("asserts");
@@ -977,7 +977,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_query(&mut self, n: &TsTypeQuery) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         keyword!("typeof");
         space!();
@@ -994,7 +994,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_type_ref(&mut self, n: &TsTypeRef) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         emit!(n.type_name);
 
@@ -1015,7 +1015,7 @@ impl<'a> Emitter<'a> {
 
     #[emitter]
     fn emit_ts_union_type(&mut self, n: &TsUnionType) -> Result {
-        self.emit_leading_comments_of_pos(n.span().lo(), false)?;
+        self.emit_leading_comments_of_span(n.span(), false)?;
 
         self.emit_list(n.span, Some(&n.types), ListFormat::UnionTypeConstituents)?;
     }
